@@ -3,6 +3,8 @@ import json
 #for Internal Test
 import sys
 from sys import platform
+import numpy as np
+
 # sys.path.append('/Users/sakdaloetpipatwanich/Desktop/SAKDAS/sakdas_dm/sakdas_v052021/sakdas')
 # from Commander import Commander
 
@@ -20,6 +22,14 @@ class load:
         self.auditing_config    = kwargs.get('auditing_config', None)
         self.report_config      = kwargs.get('report_config', None)
 
+        def replaceCustomMissing(df, auditing_config):
+           
+            if (len(auditing_config["audit"]["define_custom_missing_value"]) > 0):
+                customMissing = auditing_config["audit"]["define_custom_missing_value"]
+                
+                df = df.replace(customMissing, np.nan)
+            print(df)
+            return df
         def checkPlatform():
             userPlatform = None
             if platform == "linux" or platform == "linux2" or platform == "darwin":
@@ -78,6 +88,7 @@ class load:
                 
         #----------------------------------Start Sakda-----------------------
         self.userPlatform = checkPlatform()
+        self.df         = replaceCustomMissing(self.df, self.auditing_config)
         result          = Commander(self).action()
         data_profile    = result['data_profile']
         data_auditing   = result['data_auditing']
@@ -93,6 +104,7 @@ class load:
         self.profile_json       = data_profile.profile_json
         self.column_profile     = data_profile.column_profile
         self.column_profile_json = data_profile.column_profile_json
+
         if self.userPlatform == "Window":
             path_to_output = "{}\{}".format(path_to_output, self.dataset_name)
             print('====> {}\{}\csv\\'.format(path_to_output, data_profile.profile['profile_id']))
